# -*- coding: utf-8 -*-


from __future__ import unicode_literals, absolute_import


from django import forms



class CleanStringFormMixin(object):
    """
        Strip spaces from all text fields, replace windows line break by
        unix line break and replace MS Office quotes by ASCII single quote.
    """
    def clean(self):
        cleaned_data = super(CleanStringFormMixin, self).clean()
        for field in cleaned_data:
            if isinstance(cleaned_data[field], basestring):
                cleaned_data[field] = (
                    cleaned_data[field].replace('\r\n', '\n')
                    .replace(u'\u2018', "'").replace(u'\u2019', "'").strip())

        return cleaned_data


class CleanStringModelForm(CleanStringFormMixin, forms.ModelForm):
    pass



# -*- coding: utf-8 -*-

#!/usr/bin/env python
# -*- coding= UTF-8 -*-

"""
    Generate a django secret key. Does not add it to settings.py.
"""


from django.core.management.base import BaseCommand

from django_quicky.utils import secret_key


class Command(BaseCommand):

    help = 'Generates a Django secret key. Does not add it to settings.py.'

    def handle(self, *args, **kwargs):
        self.stdout.write(secret_key())




# -*- coding: utf-8 -*-

"""
    Delete migrations
"""

import os
import re
import glob

from django.core.management.base import BaseCommand, CommandError
from django.conf import settings
from django.apps import apps
from django.core.management import call_command


class Command(BaseCommand):

    help = 'Delete numered migrations, all tables, then makemigrations and migrate'

    def add_arguments(self, parser):
        parser.add_argument('apps', nargs='*')

    def handle(self, *args, **options):
        own_apps = set(getattr(settings, 'OWN_APPS', []))
        if not own_apps:
            raise CommandError(
                "You need to put a list of your own apps in settings.OWN_APPS"
            )

        installed_apps = set(settings.INSTALLED_APPS)

        bad_apps = ", ".join(own_apps.difference(installed_apps))
        if bad_apps:
            raise CommandError((
                "All apps in settings.OWN_APPS must be in "
                "settings.INSTALLED_APPS. Those are not: {}"
            ).format(bad_apps))

        selected_apps = set(options['apps'] or own_apps)

        bad_apps = ", ".join(selected_apps.difference(own_apps))
        if bad_apps:
            raise CommandError((
                "All apps passed in parameters must be in settings.OWN_APPS. "
                "Those are not: {}"
            ).format(bad_apps))

        apps_list = [a for n, a in apps.app_configs.items() if a.name in selected_apps]

        for app in apps_list:

            for model in app.get_models():
                model.objects.raw(
                    'DROP TABLE {}'.format( model._meta.db_table)
                )

            migrations_files = os.path.join(app.path, 'migrations', '*.py')
            for f in glob.glob(migrations_files):
                if re.match(r'\d\d\d\d', os.path.basename(f)):
                    self.stdout.write("Deleting " + f)
                    os.remove(f)

        for app in apps_list:
                call_command('makemigrations', app.label)

        for app in apps_list:
            call_command('migrate', app.label)

        for app in apps_list:
            migrations_files = os.path.join(app.path, 'fixtures', '*.json')
            for f in glob.glob(migrations_files):
                self.stdout.write("Loading " + f)
                call_command('loaddata', f)




# -*- coding: utf-8 -*-

import os
import random
import warnings


__all__ = ["generate_secret_key", "secret_key_from_file"]


def generate_secret_key():
    """
        Returns a Django secret key.
    """
    source = 'abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)'
    choices = (random.SystemRandom().choice(source) for i in range(50))
    return ''.join(choices)


def secret_key_from_file(file_path):
    """
        Get the secret key from the given file. If the file doesn't exists,
        generate a secret key, save it in this file, an returns it.
    """

    if not os.path.isfile(file_path):
        with open(file_path, 'w') as f:
            f.write(generate_secret_key())
        warnings.warn("The secret key as been generated. Don't "
                      "forget to add '%s' to you ignore lists." % file_path)

    return open(file_path).read().strip()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4 nu


import imp
import os
import sys
import io
import random
import string

try:
    import pwd
except ImportError:
    pwd = None

try:
    import grp
except ImportError:
    grp = None

from django.http import HttpResponse
try:
    from django.core.management import setup_environ
except  ImportError:
    from django.conf import settings
    setup_environ = lambda module: settings.configure(**module.__dict__)



class HttpResponseException(HttpResponse, Exception):
    pass


def setting(name, default=None):
    """
        Gets settings from django.conf if exists, returns default value otherwise

        Example:

        DEBUG = setting('DEBUG', False)
    """
    from django.conf import settings
    return getattr(settings, name, default)


def get_client_ip(request):
    """
        Return the client IP address as a string.
    """
    x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR')
    if x_forwarded_for:
        return x_forwarded_for.split(',')[0]

    return request.META.get('REMOTE_ADDR')


def load_config(path, starting_point='.', settings_module='settings'):
    """
        Add the settings directory to the sys.path, import the settings and
        configure django with it.

        You can path an absolute or a relative path to it.

        If you choose to use a relative path, it will be relative to
        `starting_point` by default, which is set to '.'.

        You may want to set it to something like __file__ (the basename will
        be stripped, and the current file's parent directory will be used
        as a starting point, which is probably what you expect in the
        first place).

        :example:

        >>> load_config('../../settings.py', __file__)
    """

    if not os.path.isabs(path):

        if os.path.isfile(starting_point):
            starting_point = os.path.dirname(starting_point)

        path = os.path.join(starting_point, path)

    path = os.path.realpath(os.path.expandvars(os.path.expanduser(path)))

    if os.path.isfile(path):
        module = os.path.splitext(os.path.basename(path))[0]
        path = os.path.dirname(path)
    else:
        module = os.path.environ.get('DJANGO_SETTINGS_MODULE', settings_module)

    sys.path.append(path)

    f, filename, desc = imp.find_module(module, [path])
    project = imp.load_module(module, f, filename, desc)
    setup_environ(project)


def secret_key(size=50):
    pool = string.ascii_letters + string.digits + string.punctuation
    return "".join(random.SystemRandom().choice(pool) for i in range(size))


def secret_key_from_file(
        file_path,
        create=True,
        size=50,
        file_perms=None,  # unix only, mayby allow windows perm scheme later ?
        file_user=None,  # unix only
        file_group=None  # unix only
    ):

    try:
        with io.open(file_path) as f:
            return f.read().strip()

    except FileNotFoundError as e:

        if not create:
            raise

        with io.open(file_path, 'w') as f:
            key = secret_key(size)
            f.write(key)

        if any((file_perms, file_user, file_group)) and not pwd:
            raise ValueError('File chmod and chown are for Unix only')

        if file_user:
            os.chown(file_path, uid=pwd.getpwnam(file_user).pw_uid)

        if file_group:
            os.chown(file_path, gid=grp.getgrnam(file_group).gr_gid)

        if file_perms:
            os.chmod(file_path, int(str(file_perms), 8))

        return key


def get_secret_key(
        file_path=None,
        create=True,
        size=50,
        file_perms=None,
        file_user=None,
        file_group=None,
        env_var="DJANGO_SECRET_KEY"
    ):
    try:
        return os.environ[env_var]
    except KeyError:
        if file_path:
            return secret_key_from_file(
                file_path,
                create,
                size,
                file_perms,
                file_user,
                file_group
            )
        raise



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: ai ts=4 sts=4 et sw=4 nu

from __future__ import absolute_import


import django

VERSION = __version__ = "0.7"

from .decorators import view, routing
from .utils import setting, load_config
from .models import get_object_or_none
from .deploy import secret_key_from_file